lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite: Windows password security audit tool. GUI, reports in PDF.
[<prev] [next>] [<thread-prev] [thread-next>] [day] [month] [year] [list]
Date:	Wed, 5 Aug 2009 19:10:28 -0700
From:	"Luis R. Rodriguez" <lrodriguez@...eros.com>
To:	Andrew Morton <akpm@...ux-foundation.org>
CC:	Luis Rodriguez <Luis.Rodriguez@...eros.com>,
	"joe@...ches.com" <joe@...ches.com>,
	"torvalds@...ux-foundation.org" <torvalds@...ux-foundation.org>,
	"linux-kernel@...r.kernel.org" <linux-kernel@...r.kernel.org>,
	"mcgrof@...il.com" <mcgrof@...il.com>
Subject: Re: [PATCH 3/3] checkincludes.pl: add option to remove duplicates
 in place

On Wed, Aug 05, 2009 at 06:59:45PM -0700, Andrew Morton wrote:
> On Wed, 5 Aug 2009 17:51:12 -0700 "Luis R. Rodriguez" <lrodriguez@...eros.com> wrote:
> 
> > checkincludes.pl is more useful if it actually removed
> > the lines. This adds support for that with -r.
> >
> 
> hm, spose so.  It can't do any harm.
> 
> Plus it's about time we edited that file - it hasn't been changed since
> we started the bk tree.

Hehe yeah.. Anno Domini

> > ---
> >  scripts/checkincludes.pl |   57 +++++++++++++++++++++++++++++++++++++++++-----
> >  1 files changed, 51 insertions(+), 6 deletions(-)
> >
> > diff --git a/scripts/checkincludes.pl b/scripts/checkincludes.pl
> > index 4bff139..5a53407 100755
> > --- a/scripts/checkincludes.pl
> > +++ b/scripts/checkincludes.pl
> > @@ -2,32 +2,77 @@
> >  #
> >  # checkincludes: Find files included more than once in (other) files.
> >  # Copyright abandoned, 2000, Niels Kristian Bech Jensen <nkbj@...ge.dk>.
> > +# Copyright abandoned, 2009, Luis R. Rodriguez <mcgrof@...il.com>
> >
> >  sub usage {
> > -     print "Usage: checkincludes.pl <file list>\n";
> > +     print "Usage: checkincludes.pl [-r]\n";
> > +     print "By default we just warn of duplicates\n";
> > +     print "To remove files in place use -r\n";
> 
> I'm not sure I like the wording here - I don't _want_ my files removed!
> 
> This?
> 
> --- a/scripts/checkincludes.pl~checkincludespl-add-option-to-remove-duplicates-in-place-fix
> +++ a/scripts/checkincludes.pl
> @@ -7,7 +7,7 @@
>  sub usage {
>         print "Usage: checkincludes.pl [-r]\n";
>         print "By default we just warn of duplicates\n";
> -       print "To remove files in place use -r\n";
> +       print "To remove duplicated includes in place use -r\n";
>         exit 1;
>  }

Sure, attached new v2

From: Luis R. Rodriguez <lrodriguez@...eros.com>
Subject: [PATCH v2] checkincludes.pl: add option to remove duplicates in place

checkincludes.pl is more useful if it actually removed
the lines. This adds support for that with -r.

Signed-off-by: Luis R. Rodriguez <lrodriguez@...eros.com>
---

Now with Andrew's change in place and some sort of documentation added.

 scripts/checkincludes.pl |   66 +++++++++++++++++++++++++++++++++++++++++-----
 1 files changed, 59 insertions(+), 7 deletions(-)

diff --git a/scripts/checkincludes.pl b/scripts/checkincludes.pl
index 4bff139..676ddc0 100755
--- a/scripts/checkincludes.pl
+++ b/scripts/checkincludes.pl
@@ -1,33 +1,85 @@
 #!/usr/bin/perl
 #
 # checkincludes: Find files included more than once in (other) files.
 # Copyright abandoned, 2000, Niels Kristian Bech Jensen <nkbj@...ge.dk>.
+# Copyright 2009 Luis R. Rodriguez <mcgrof@...il.com>
+#
+# This script checks for duplicate includes. It also has support
+# to remove them in place. Note that this will not take into
+# consideration macros so you should run this only if you know
+# you do have real dups and do not have them under #ifdef's. You
+# could also just review the results.
 
 sub usage {
-	print "Usage: checkincludes.pl <file list>\n";
+	print "Usage: checkincludes.pl [-r]\n";
+	print "By default we just warn of duplicates\n";
+	print "To remove duplicated includes in place use -r\n";
 	exit 1;
 }
 
+my $remove = 0;
+
 if ($#ARGV < 0) {
-        usage();
+	usage();
+}
+
+if ($#ARGV >= 1) {
+	if ($ARGV[0] =~ /^-/) {
+		if ($ARGV[0] eq "-r") {
+			$remove = 1;
+			shift;
+		} else {
+			usage();
+		}
+	}
 }
 
 foreach $file (@ARGV) {
 	open(FILE, $file) or die "Cannot open $file: $!.\n";
 
 	my %includedfiles = ();
+	my @file_lines = ();
 
 	while (<FILE>) {
 		if (m/^\s*#\s*include\s*[<"](\S*)[>"]/o) {
 			++$includedfiles{$1};
 		}
+		push(@file_lines, $_);
 	}
 
 	close(FILE);
-	
-	foreach $filename (keys %includedfiles) {
-		if ($includedfiles{$filename} > 1) {
-			print "$file: $filename is included more than once.\n";
+
+	if (!$remove) {
+		foreach $filename (keys %includedfiles) {
+			if ($includedfiles{$filename} > 1) {
+				print "$file: $filename is included more than once.\n";
+			}
 		}
+		next;
 	}
+
+	open(FILE,">$file") || die("Cannot write to $file: $!");
+
+	my $dups = 0;
+	foreach (@file_lines) {
+		if (m/^\s*#\s*include\s*[<"](\S*)[>"]/o) {
+			foreach $filename (keys %includedfiles) {
+				if ($1 eq $filename) {
+					if ($includedfiles{$filename} > 1) {
+						$includedfiles{$filename}--;
+						$dups++;
+					} else {
+						print FILE $_;
+					}
+				}
+			}
+		} else {
+			print FILE $_;
+		}
+	}
+	if ($dups > 0) {
+		print "$file: removed $dups duplicate includes\n";
+	}
+	close(FILE);
 }
@@ -1,33 +1,85 @@
 #!/usr/bin/perl
 #
-# checkincludes: Find files included more than once in (other) files.
+# checkincludes: find/remove files included more than once
+#
 # Copyright abandoned, 2000, Niels Kristian Bech Jensen <nkbj@...ge.dk>.
-- 
1.6.3.3

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@...r.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Powered by blists - more mailing lists

Powered by Openwall GNU/*/Linux Powered by OpenVZ